@@ -1,17 +1,17 @@
 # SystemC - SystemC Perl Interface
-# $Id: Netlist.pm 49154 2008-01-02 14:22:02Z wsnyder $
+# $Id: Netlist.pm 59485 2008-08-21 13:41:55Z wsnyder $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
 # Copyright 2001-2008 by Wilson Snyder.  This program is free software;
 # you can redistribute it and/or modify it under the terms of either the GNU
 # General Public License or the Perl Artistic License.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 ######################################################################
 
 package SystemC::Netlist;
@@ -27,14 +27,7 @@ use Verilog::Netlist::Subclass;
 use strict;
 use vars qw($Debug $Verbose $VERSION);
 
-$VERSION = '1.282';
-
-######################################################################
-#### Error Handling
-
-# Netlist file & line numbers don't apply
-sub filename { return 'SystemC::Netlist'; }
-sub lineno { return ''; }
+$VERSION = '1.284';
 
 ######################################################################
 #### Creation
@@ -56,6 +49,22 @@ sub new {
     return $self;
 }
 
+######################################################################
+#### Error Handling
+
+# Netlist file & line numbers don't apply
+sub filename { return 'SystemC::Netlist'; }
+sub lineno { return ''; }
+
+sub new_logger {
+    # Undocumented, as only for backward compatibility before Verilog-Perl 3.041
+    if ($::Verilog::Netlist::Logger::{new}) {  # Function exists
+	return Verilog::Netlist::Logger->new(@_);
+    } else {
+	return undef;
+    }
+}
+
 ######################################################################
 #### Utilities
 
@@ -369,9 +378,9 @@ Return the version number of SystemC.
 
 =head1 DISTRIBUTION
 
-SystemPerl is part of the L<http://www.veripool.com/> free SystemC software
+SystemPerl is part of the L<http://www.veripool.org/> free SystemC software
 tool suite.  The latest version is available from CPAN and from
-L<http://www.veripool.com/systemperl.html>.
+L<http://www.veripool.org/systemperl>.
 
 Copyright 2001-2008 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
