@@ -1,17 +1,17 @@
 # SystemC - SystemC Perl Interface
-# $Id: Class.pm 49154 2008-01-02 14:22:02Z wsnyder $
+# $Id: Class.pm 59485 2008-08-21 13:41:55Z wsnyder $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
 # Copyright 2005-2008 by Wilson Snyder.  This program is free software;
 # you can redistribute it and/or modify it under the terms of either the GNU
 # General Public License or the Perl Artistic License.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 ######################################################################
 
 package SystemC::Netlist::Class;
@@ -24,7 +24,7 @@ use SystemC::Template;
 use Verilog::Netlist::Subclass;
 @ISA = qw(SystemC::Netlist::Class::Struct
 	  Verilog::Netlist::Subclass);
-$VERSION = '1.282';
+$VERSION = '1.284';
 use strict;
 
 structs('new',
@@ -44,7 +44,7 @@ structs('new',
 	   # For special procedures
 	   _nets	=> '%',		# List of nets if this is tracable
 	   ]);
-	
+
 ######################################################################
 # List of basic C++ types and their sizes
 
@@ -104,6 +104,8 @@ sub generate_class {
 ######################################################################
 #### Accessors
 
+sub logger { return $_[0]->netlist->logger; }
+
 sub sc_type { return $_[0]->convert_type || $_[0]->name; }
 
 sub is_sc_bv {
@@ -238,9 +240,9 @@ Prints debugging information for this file.
 
 =head1 DISTRIBUTION
 
-SystemPerl is part of the L<http://www.veripool.com/> free SystemC software
+SystemPerl is part of the L<http://www.veripool.org/> free SystemC software
 tool suite.  The latest version is available from CPAN and from
-L<http://www.veripool.com/systemperl.html>.
+L<http://www.veripool.org/systemperl>.
 
 Copyright 2001-2008 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
