@@ -1,17 +1,17 @@
 # SystemC - SystemC Perl Interface
-# $Id: Method.pm 49154 2008-01-02 14:22:02Z wsnyder $
+# $Id: Method.pm 59485 2008-08-21 13:41:55Z wsnyder $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
 # Copyright 2005-2008 by Wilson Snyder.  This program is free software;
 # you can redistribute it and/or modify it under the terms of either the GNU
 # General Public License or the Perl Artistic License.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 ######################################################################
 
 package SystemC::Netlist::Method;
@@ -24,7 +24,7 @@ use SystemC::Template;
 use Verilog::Netlist::Subclass;
 @ISA = qw(SystemC::Netlist::Method::Struct
 	  Verilog::Netlist::Subclass);
-$VERSION = '1.282';
+$VERSION = '1.284';
 use strict;
 
 structs('new',
@@ -32,13 +32,17 @@ structs('new',
 	=>[name     	=> '$', #'	# Name of the module
 	   filename 	=> '$', #'	# Filename this came from
 	   lineno	=> '$', #'	# Linenumber this came from
-	   sensitive	=> '$', #'	# Sensitivity information
 	   userdata	=> '%',		# User information
+	   #
+	   module	=> '$', #'	# Module method is in
+	   sensitive	=> '$', #'	# Sensitivity information
 	   ]);
-	
+
 ######################################################################
 ######################################################################
-#### Methods
+#### Accessors
+
+sub logger { return $_[0]->module->logger; }
 
 ######################################################################
 #### Linking
@@ -118,9 +122,9 @@ Prints debugging information for this file.
 
 =head1 DISTRIBUTION
 
-SystemPerl is part of the L<http://www.veripool.com/> free SystemC software
+SystemPerl is part of the L<http://www.veripool.org/> free SystemC software
 tool suite.  The latest version is available from CPAN and from
-L<http://www.veripool.com/systemperl.html>.
+L<http://www.veripool.org/systemperl>.
 
 Copyright 2005-2008 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
