@@ -1,17 +1,17 @@
 # SystemC - SystemC Perl Interface
-# $Id: Module.pm 49154 2008-01-02 14:22:02Z wsnyder $
+# $Id: Module.pm 59485 2008-08-21 13:41:55Z wsnyder $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
 # Copyright 2001-2008 by Wilson Snyder.  This program is free software;
 # you can redistribute it and/or modify it under the terms of either the GNU
 # General Public License or the Perl Artistic License.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 ######################################################################
 
 package SystemC::Netlist::Module;
@@ -28,7 +28,7 @@ use SystemC::Netlist::AutoCover;
 use SystemC::Netlist::AutoTrace;
 
 @ISA = qw(Verilog::Netlist::Module);
-$VERSION = '1.282';
+$VERSION = '1.284';
 use strict;
 
 # Some attributes we use:
@@ -68,7 +68,7 @@ sub new_pin_template {
     my $self = shift;
     # @_ params
     # Create a new pin template under this module
-    my $templref = new SystemC::Netlist::PinTemplate (@_,);
+    my $templref = new SystemC::Netlist::PinTemplate (@_, module=>$self,);
     push @{$self->_pintemplates}, $templref;
     return $templref;
 }
@@ -355,9 +355,9 @@ pin.
 
 =head1 DISTRIBUTION
 
-SystemPerl is part of the L<http://www.veripool.com/> free SystemC software
+SystemPerl is part of the L<http://www.veripool.org/> free SystemC software
 tool suite.  The latest version is available from CPAN and from
-L<http://www.veripool.com/systemperl.html>.
+L<http://www.veripool.org/systemperl>.
 
 Copyright 2001-2008 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
