@@ -1,17 +1,17 @@
 # SystemC - SystemC Perl Interface
-# $Id: Pin.pm 49154 2008-01-02 14:22:02Z wsnyder $
+# $Id: Pin.pm 59485 2008-08-21 13:41:55Z wsnyder $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
 # Copyright 2001-2008 by Wilson Snyder.  This program is free software;
 # you can redistribute it and/or modify it under the terms of either the GNU
 # General Public License or the Perl Artistic License.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 ######################################################################
 
 package SystemC::Netlist::Pin;
@@ -24,7 +24,7 @@ use SystemC::Netlist::Net;
 use SystemC::Netlist::Cell;
 use SystemC::Netlist::Module;
 @ISA = qw(Verilog::Netlist::Pin);
-$VERSION = '1.282';
+$VERSION = '1.284';
 use strict;
 
 ######################################################################
@@ -58,7 +58,7 @@ sub _autos {
 		     filename=>$self->module->filename,
 		     lineno=>$self->lineno . ':(AUTOSIGNAL)',
 		     type=>$self->port->type,
-		     comment=>" For ".$self->submod->name, #.".".$self->name, 
+		     comment=>" For ".$self->submod->name, #.".".$self->name,
 		     module=>$self->module, sp_autocreated=>1,)
 		    ->_link;
 		# We need to track where we insert this, so we can insert
@@ -84,6 +84,7 @@ structs('new',
 	=>[filename 	=> '$', #'	# Filename this came from
 	   lineno	=> '$', #'	# Linenumber this came from
 	   #
+	   module	=> '$', #'	# Module part of
 	   cellregexp	=> '$', #'	# Cell regular expression as string
 	   cellre	=> '$', #'	# Cell regular expression compiled
 	   pinregexp	=> '$', #'	# Pin regular expression as string
@@ -93,6 +94,8 @@ structs('new',
 	   netregexp	=> '$', #'	# Net regular expression as string
 	   ]);
 
+sub logger { return $_[0]->module->logger; }
+
 ######################################################################
 #### Package return
 1;
@@ -111,9 +114,9 @@ pin.
 
 =head1 DISTRIBUTION
 
-SystemPerl is part of the L<http://www.veripool.com/> free SystemC software
+SystemPerl is part of the L<http://www.veripool.org/> free SystemC software
 tool suite.  The latest version is available from CPAN and from
-L<http://www.veripool.com/systemperl.html>.
+L<http://www.veripool.org/systemperl>.
 
 Copyright 2001-2008 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
