@@ -1,15 +1,15 @@
-#$Id: Parser.pm 49154 2008-01-02 14:22:02Z wsnyder $
+#$Id: Parser.pm 59485 2008-08-21 13:41:55Z wsnyder $
 ######################################################################
 #
 # Copyright 2001-2008 by Wilson Snyder.  This program is free software;
 # you can redistribute it and/or modify it under the terms of either the GNU
 # General Public License or the Perl Artistic License.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-#                                                                           
+#
 ######################################################################
 
 package SystemC::Parser;
@@ -21,7 +21,7 @@ require DynaLoader;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '1.282';
+$VERSION = '1.284';
 
 ######################################################################
 #### Configuration Section
@@ -225,9 +225,9 @@ stripped // Auto inserted comments.
 
 =head1 DISTRIBUTION
 
-SystemPerl is part of the L<http://www.veripool.com/> free SystemC software
+SystemPerl is part of the L<http://www.veripool.org/> free SystemC software
 tool suite.  The latest version is available from CPAN and from
-L<http://www.veripool.com/systemperl.html>.
+L<http://www.veripool.org/systemperl>.
 
 Copyright 2001-2008 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
