@@ -1,17 +1,17 @@
 # SystemC - SystemC Perl Interface
-# $Id: Template.pm 49154 2008-01-02 14:22:02Z wsnyder $
+# $Id: Template.pm 59485 2008-08-21 13:41:55Z wsnyder $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
 # Copyright 2001-2008 by Wilson Snyder.  This program is free software;
 # you can redistribute it and/or modify it under the terms of either the GNU
 # General Public License or the Perl Artistic License.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 ######################################################################
 
 package SystemC::Template;
@@ -27,12 +27,14 @@ use Verilog::Netlist::Subclass;
 use strict;
 use vars qw ($Debug $Default_Self $VERSION);
 
-$VERSION = '1.282';
+$VERSION = '1.284';
 
 structs('_new_base',
 	'SystemC::Template::Struct'
 	=>[name		=> '$', #'	# Filename this came from
 	   lineno	=> '$', #'	# Line number (for warning messages)
+	   logger	=> '$', #'	# Error logger object
+	   #
 	   verbose	=> '$', #'	# If true, tell when the file is written
 	   ppline	=> '$', #'	# If true, put out #line directives
 	   keep_timestamp=> '$', #'	# If true, don't write the file if it didn't change
@@ -41,7 +43,7 @@ structs('_new_base',
 	   # For _write
 	   out_text	=> '$',	#'	# ARRAYREF: Lines of text to output
 	   ]);
-	
+
 ######################################################################
 ######################################################################
 #### Creation
@@ -205,6 +207,8 @@ sub write {
 	|| (join ('',@old_text) ne join ('',@gen_text))) {
 	print "Write $filename\n" if $self->verbose;
 	my $fh = IO::File->new (">$filename.tmp") or die "%Error: $! $filename.tmp\n";
+	# When Verilog-Perl 3.041 is the minimum supported version,
+	# this should become $self->logger->unlink_if_error
         $self->unlink_if_error ("$filename.tmp");
 	print $fh @gen_text;
 	$fh->close();
@@ -305,9 +309,9 @@ Adds to the out_text the given formatted text.
 
 =head1 DISTRIBUTION
 
-SystemPerl is part of the L<http://www.veripool.com/> free SystemC software
+SystemPerl is part of the L<http://www.veripool.org/> free SystemC software
 tool suite.  The latest version is available from CPAN and from
-L<http://www.veripool.com/systemperl.html>.
+L<http://www.veripool.org/systemperl>.
 
 Copyright 2001-2008 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
